import React from 'react'
import { storiesOf } from '@storybook/react'

const stories = storiesOf('Styles', module)

stories
  .add('Typography', () => (
    <React.Fragment>
      <h2>Headings</h2>
      <hr />
      <h1>h1. Example heading</h1>
      <h2>h2. Example heading</h2>
      <h3>h3. Example heading</h3>
      <h4>h4. Example heading</h4>
      <h5>h5. Example heading</h5>
      <h6>h6. Example heading</h6>
    </React.Fragment>
  ))
  .add('Text', () => (
    <React.Fragment>
      <h2>Text alignment</h2>
      <hr />
      <p className="text-left">Left aligned text on all viewport sizes.</p>
      <p className="text-center">Center aligned text on all viewport sizes.</p>
      <p className="text-right">Right aligned text on all viewport sizes.</p>

      <p className="sm-text-left text-right">
        Left aligned text on viewports sized SM (small) or wider.
      </p>
      <p className="md-text-left text-right">
        Left aligned text on viewports sized MD (medium) or wider.
      </p>
      <p className="lg-text-left text-right">
        Left aligned text on viewports sized LG (large) or wider.
      </p>
      <p className="xl-text-left text-right">
        Left aligned text on viewports sized XL (extra-large) or wider.
      </p>
    </React.Fragment>
  ))
  .add('Grid', () => (
    <div className="grid">
      <h2>Grid</h2>
      <div className="child-cn m-b row text-center">
        <div className="col-1" />
        <div className="col-offset-1 col-2" />
        <div className="col-offset-2 col-6" />
      </div>

      <div className="child-cn row m-b text-center">
        <div className="col-2" />
        <div className="col-2" />
        <div className="col" />
        <div className="col-auto" />
      </div>

      <div className="child-cn row m-b text-center">
        <div className="col-auto" />
        <div className="col-auto" />
        <div className="col-auto" />
      </div>

      <div className="child-cn row m-b text-center">
        <div className="col-3 col-offset-3" />
        <div className="col-auto" />
      </div>

      <div className="child-cn row m-b text-center">
        <div className="col" />
        <div className="col" />
        <div className="col" />
        <div className="col" />
      </div>

      <div className="row m-b text-center center">
        <div className="col-6">{`.row.center > .col-6`}</div>
      </div>

      <div className="child-cn row m-b text-center">
        <div className="col-4 last">1</div>
        <div className="col-4">2</div>
        <div className="col-4">3</div>
      </div>
    </div>
  ))
  .add('Paddings', () => (
    <div className="row gutter">
      <h3 className="col-12">Each class can have suffix (xs / sm / md / lg / 2 / 3)</h3>

      <div className="col child-cn child-highlight">
        <div className="p-a" />
        <div className="p-r" />
        <div className="p-l" />
        <div className="p-x" />
      </div>

      <div className="col child-cn child-highlight">
        <div className="p-b" />
        <div className="p-t" />
        <div className="p-y" />
      </div>

      <div className="col child-cn child-highlight">
        <div className="p-l-xs" />
        <div className="p-l-sm" />
        <div className="p-l" />
        <div className="p-l-md" />
        <div className="p-l-2" />
        <div className="p-l-3" />
      </div>
    </div>
  ))
  .add('Margins', () => (
    <div className="row gutter">
      <h3 className="col-12">Each class can have suffix (xs / sm / md / lg / 2 / 3)</h3>

      <div className="col">
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-a" />
        </div>
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-r" />
        </div>
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-l" />
        </div>
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-x" />
        </div>
      </div>

      <div className="col">
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-b" />
        </div>

        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-t" />
        </div>

        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-y" />
        </div>
      </div>

      <div className="col">
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-l-xs" />
        </div>
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-l-sm" />
        </div>
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-l" />
        </div>
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-l-md" />
        </div>
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-l-2" />
        </div>
        <div className="marginWrapper child-cn child-highlight2">
          <div className="m-l-3" />
        </div>
      </div>
    </div>
  ))
  .add('Colors', () => (
    <div>
      <h2>Colors</h2>
      <p className="text-primary">.text-primary</p>
      <p className="text-accent">.text-accent</p>
      <p className="text-success">.text-success</p>
      <p className="text-danger">.text-danger</p>
      <p className="text-warning">.text-warning</p>
      <p className="text-info">.text-info</p>
      <p className="text-secondary">.text-secondary</p>
      <p className="text-white bg-dark">.text-white</p>
      <h3>Colors with links</h3>
      <p>
        Contextual text classes also work well on links with the provided hover and focus states.
      </p>
      <p>
        <a href="#" className="text-primary">
          Primary link
        </a>
      </p>
      <p>
        <a href="#" className="text-accent">
          Accent link
        </a>
      </p>
      <p>
        <a href="#" className="text-success">
          Success link
        </a>
      </p>
      <p>
        <a href="#" className="text-danger">
          Danger link
        </a>
      </p>
      <p>
        <a href="#" className="text-warning">
          Warning link
        </a>
      </p>
      <p>
        <a href="#" className="text-info">
          Info link
        </a>
      </p>
      <p>
        <a href="#" className="text-secondary">
          Secondary link
        </a>
      </p>
      <p>
        <a href="#" className="text-white bg-black">
          White link
        </a>
      </p>
    </div>
  ))
  .add('Background color', () => (
    <div>
      <h2>Background color</h2>
      <div className="p-a m-b-sm bg-primary text-white">.bg-primary</div>
      <div className="p-a m-b-sm bg-accent text-white">.bg-accent</div>
      <div className="p-a m-b-sm bg-success text-white">.bg-success</div>
      <div className="p-a m-b-sm bg-danger text-white">.bg-danger</div>
      <div className="p-a m-b-sm bg-warning">.bg-warning</div>
      <div className="p-a m-b-sm bg-info text-white">.bg-info</div>
      <div className="p-a m-b-sm bg-black text-white">.bg-black</div>
      <div className="p-a m-b-sm bg-white">.bg-white</div>
    </div>
  ))
