import cm from './Btn.module.styl'
import React from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import Loader from 'components/Loader'

export default class Btn extends React.Component {
  static propTypes = {
    className: PropTypes.string,
    style: PropTypes.object,

    label: PropTypes.node,
    children: PropTypes.node,

    primary: PropTypes.bool,
    success: PropTypes.bool,
    danger: PropTypes.bool,
    accent: PropTypes.bool,

    inverse: PropTypes.bool,

    xs: PropTypes.bool,
    sm: PropTypes.bool,
    lg: PropTypes.bool,
    fullWidth: PropTypes.bool,
    multiline: PropTypes.bool,

    active: PropTypes.bool,
    disabled: PropTypes.bool,

    loader: PropTypes.bool,

    target: PropTypes.any,

    type: PropTypes.string,

    href: PropTypes.string,
    to: PropTypes.string,

    onClick: PropTypes.func,
  }

  static defaultProps = {
    type: 'button',
  }

  handleClick = e => {
    this.props.onClick && this.props.onClick(e)
  }

  render() {
    const {
      className,
      style,
      label,
      children,
      primary,
      success,
      danger,
      accent,
      inverse,
      xs,
      sm,
      lg,
      fullWidth,
      multiline,
      active,
      disabled,
      loader,
      target,
      type = 'button',
      href,
      // to,
      ...other
    } = this.props

    let _style = Object.assign({ position: 'relative' }, style)

    let Component = 'button'
    const props = {
      ...other,
      disabled: disabled,
      onClick: this.handleClick,
      className: cx(className, cm.btn, {
        [cm.primary]: primary,
        [cm.success]: success,
        [cm.danger]: danger,
        [cm.inverse]: inverse,
        [cm.active]: active,
        [cm.accent]: accent,
        [cm.xs]: xs,
        [cm.sm]: sm,
        [cm.lg]: lg,
        [cm.fullWidth]: fullWidth,
        [cm.multiline]: multiline,
      }),
      style: _style,
    }

    // if (to) {
    //   Component = Link
    //   props.to = href || to
    // } else
    if (href || target) {
      Component = 'a'
      props.target = target
      props.href = href
    } else {
      props.type = type
    }

    return (
      <Component {...props}>
        {children || label}
        {loader ? <Loader center color="rgba(0,0,0,.36)" size={20} /> : null}
      </Component>
    )
  }
}
