import cm from './NavTabs.module.styl'
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import SvgIcon from 'components/misc/SvgIcon/SvgIcon'
import { CLOSE } from 'constants/icons'
import { isClickInElement } from 'utils/DOM'
import EventListener from 'utils/listener'

export default class NavTabs extends Component {
  static propTypes = {
    name: PropTypes.string,
    onChange: PropTypes.func,
    onClose: PropTypes.func,
    onOrder: PropTypes.func,
    options: PropTypes.array,
    renderLabel: PropTypes.func,
    value: PropTypes.string,
  }

  static defaultProps = {
    options: [],
  }

  state = { dragValue: '', dragOrder: null, fakeTabs: 0 }

  handleTabClick = e => {
    const { name, onChange, onClose } = this.props
    const { value } = e.currentTarget.dataset
    const result = { target: { value, name } }

    const closeEl = e.currentTarget.querySelector('[data-action="close"]')
    if (closeEl && isClickInElement(e, closeEl)) {
      const isActive = value === this.props.value
      const options = [...this.props.options]

      onClose({ ...result })
      this.setState({ fakeTabs: this.state.fakeTabs + 1 })

      if (!isActive || options.length <= 1) {
        return
      }

      let index = options.findIndex(o => o.value === value)
      const isLast = index === options.length - 1
      index = index + (isLast ? -1 : 1)
      result.target.value = options[index].value
    }

    onChange(result)
  }

  handleDragStart = e => {
    this.dragged = e.currentTarget
    const { value: dragValue } = e.currentTarget.dataset
    const { options } = this.props
    const dragOrder = options.map(o => o.value)
    this.setState({ dragValue, dragOrder })
    this.dragTimer = setTimeout(() => this.setState({ isDragging: true }), 100)
  }

  handleDragOver = e => {
    if (e.currentTarget === this.dragged || e.currentTarget.dataset.pin) {
      return
    }
    const { dragValue, dragOrder } = this.state
    const { value } = e.currentTarget.dataset
    const isForward =
      dragOrder.findIndex(i => i === dragValue) < dragOrder.findIndex(i => i === value)

    const order = dragOrder.filter(i => i !== dragValue)
    const overIndex = order.findIndex(i => i === value)
    const insertIndex = overIndex + (isForward ? 1 : 0)
    order.splice(insertIndex, 0, dragValue)
    this.setState({ dragOrder: order })
  }

  handleDragEnd = e => {
    this.dragged = null
    clearTimeout(this.dragTimer)
    const { name, options, onOrder } = this.props
    const { dragOrder } = this.state
    const res = dragOrder.map(v => options.find(o => o.value === v))
    onOrder({ target: { value: res, name } })
    this.setState({ dragValue: '', dragOrder: null, isDragging: false })
  }

  handleMouseLeave = () => this.setState({ fakeTabs: 0 })

  render() {
    const { dragValue, dragOrder, isDragging, fakeTabs } = this.state
    const { options, renderLabel, value } = this.props

    return (
      <div className="d-flex" onMouseLeave={this.handleMouseLeave}>
        {options.map((o, i) => {
          const order = dragOrder ? dragOrder.findIndex(d => d === o.value) : undefined
          const style = { order }

          if (isDragging && o.value === dragValue) {
            return <div key={o.value} className={cm.fakeTab} style={style} />
          }

          const active = o.value === value

          return (
            <div
              key={o.value}
              className={cx(cm.tab, 'o-hidden p-relative p-y-sm pointer no-select', {
                [cm.active]: active,
                [cm.pin]: o.pin,
              })}
              onClick={this.handleTabClick}
              data-value={o.value}
              data-pin={o.pin}
              draggable={!o.pin}
              onDragStart={this.handleDragStart}
              onDragOver={this.handleDragOver}
              style={style}
            >
              <div title={o.label} className={cx(cm.label, 'o-hidden p-relative text-sm')}>
                {renderLabel ? renderLabel(o, active) : o.label}
              </div>
              {!o.pin && (
                <div
                  className={cx(cm.close, 'p-absolute bg-hover rounded-circle')}
                  data-action="close"
                >
                  <SvgIcon
                    i={CLOSE}
                    size={15}
                    onClick={this.handleCloseTab}
                    data-value={o.value}
                    className="d-block text-secondary"
                  />
                </div>
              )}
            </div>
          )
        })}
        {fakeTabs > 0 &&
          Array.apply(null, Array(fakeTabs)).map((e, i) => <div key={i} className={cm.fakeTab} />)}
        <EventListener target="document" onDragEnd={this.handleDragEnd} />
      </div>
    )
  }
}
