import cm from './Checkbox.module.styl'
import cx from 'classnames'
import React from 'react'
import PropTypes from 'prop-types'
import SvgIcon from 'components/misc/SvgIcon'
import { CHECK_BOX_BG, CHECK_BOX_CHECKED, CHECK_BOX_UNCHECKED } from 'constants/icons'

const randomId = () =>
  Math.random()
    .toString(36)
    .substr(2, 5)

const CHECKBOX_SIZE = 24

class Checkbox extends React.PureComponent {
  static propTypes = {
    className: PropTypes.string,
    checked: PropTypes.bool,
    defaultChecked: PropTypes.bool,
    disabled: PropTypes.bool,
    id: PropTypes.string,
    label: PropTypes.node,
    labelId: PropTypes.string,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    style: PropTypes.object,
    value: PropTypes.string,
    white: PropTypes.bool,
  }

  state = {
    id: this.props.id || `${randomId()}-checkbox`,
  }

  render() {
    const {
      className,
      label,
      labelId,
      checked,
      value,
      style,
      disabled,
      white,
      ...other
    } = this.props

    const { id } = this.state
    let _checked = value !== undefined ? value : checked
    const wrapperCn = cx(cm.wrapper, className, {
      [cm.withoutLabel]: !label,
      [cm.white]: white,
      [cm.disabled]: disabled,
    })

    return (
      <label style={style} id={labelId} className={wrapperCn} htmlFor={id}>
        <input {...other} type="checkbox" checked={_checked} disabled={disabled} id={id} />
        <SvgIcon
          i={CHECK_BOX_CHECKED}
          size={CHECKBOX_SIZE}
          className={cx(cm.icon, cm.iconActive)}
        />
        <SvgIcon i={CHECK_BOX_BG} size={CHECKBOX_SIZE} className={cx(cm.icon, cm.iconBg)} />
        <SvgIcon i={CHECK_BOX_UNCHECKED} size={CHECKBOX_SIZE} className={cm.icon} />
        {label}
      </label>
    )
  }
}

export default Checkbox
