import cm from './Radio.module.styl'
import cx from 'classnames'
import React from 'react'
import PropTypes from 'prop-types'
import SvgIcon from 'components/misc/SvgIcon'
import { noop } from 'utils'
import { HELP_OUTLINE, RADIO_CHECKED, RADIO_UNCHECKED } from 'constants/icons'

class Radio extends React.PureComponent {
  static propTypes = {
    name: PropTypes.string,
    value: PropTypes.any,
    label: PropTypes.string,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    options: PropTypes.array,
    disabled: PropTypes.bool,
    invalid: PropTypes.bool,
    onChange: PropTypes.func,
    onClick: PropTypes.func,
    helpClassName: PropTypes.string,
    theme: PropTypes.object,
    inline: PropTypes.bool,
  }

  static defaultProps = {
    onClick: noop,
    theme: {},
  }

  state = {}

  render() {
    const {
      name,
      value,
      label,
      onFocus,
      onBlur,
      options,
      disabled,
      invalid, // eslint-disable-line no-unused-vars
      onChange,
      onClick,
      helpClassName,
      theme,
      inline,
      ...other
    } = this.props

    const wrapperCn = cx(cm.wrapper, theme.wrapper, {
      [cm.disabled]: disabled,
      [cm.inline]: inline,
    })

    return (
      <div className={wrapperCn} onClick={onClick}>
        {options.map((option, index) => {
          const checked = option.value == value
          return (
            <div
              key={option.value + '-' + index}
              className={cx(cm.option, theme.option, {
                [cm.disabled]: option.disabled,
                'm-r': inline,
              })}
              id={option.id}
            >
              <label className={cm.label}>
                <input
                  type="radio"
                  checked={checked}
                  value={option.value}
                  onChange={onChange}
                  onFocus={onFocus}
                  onBlur={onBlur}
                  name={name}
                  disabled={option.disabled || disabled}
                  {...other}
                />
                <SvgIcon
                  i={checked ? RADIO_CHECKED : RADIO_UNCHECKED}
                  size={24}
                  fill={null}
                  className={cx(cm.icon, { [cm.iconActive]: checked })}
                />
                {option.label}
                {option.tooltip && (
                  <SvgIcon
                    i={HELP_OUTLINE}
                    size={14}
                    data-title={option.tooltip}
                    className={cx(cm.tooltip, 'm-l-sm')}
                  />
                )}
              </label>
              {!!(checked && option.help) && (
                <p className={cx(cm.help, helpClassName)}>{option.help}</p>
              )}
            </div>
          )
        })}
      </div>
    )
  }
}

export default Radio
