import cm from './TextArea.module.styl'
import React from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import TextAreaAutosize from 'react-textarea-autosize'

const LINEBREAK = '\n'

class TextArea extends React.Component {
  static propTypes = {
    onChange: PropTypes.func.isRequired,
    valueType: PropTypes.string,
    minRows: PropTypes.number,
    maxRows: PropTypes.number,
  }

  static defaultProps = {
    onChange: () => { },
    valueType: 'string',
    minRows: 3,
    maxRows: 12,
  }

  state = {
    value: this.props.value || '',
  }

  UNSAFE_componentWillReceiveProps(nextProps) { // fix for jumping caret https://github.com/facebook/react/issues/955
    if (nextProps.value) {
      const _value = this.props.valueType === 'array'
        ? (nextProps.value || []).join(LINEBREAK)
        : nextProps.value
      this.setState({ value: _value })
    }
  }

  focus = () => this.textarea && this.textarea.focus()

  handleChange = (e) => {
    const { valueType, name, onChange } = this.props
    this.setState({ value: e.target.value })

    const rawVal = e.target.value
    const value = valueType === 'array' ? rawVal.replace(/\r\n/g, LINEBREAK).split(LINEBREAK) : rawVal

    onChange({ target: { value, name } })
  }

  handleBlur = (e) => {
    const { value: propsValue, name, onChange, onBlur, valueType } = this.props

    onBlur && onBlur()

    const value = valueType === 'array' ? propsValue.filter(v => v) : propsValue
    onChange({ target: { value, name } })
  }

  handleTextAreaRef = (ref) => {
    this.textarea = ref
  }

  render() {
    const {
      minRows,
      maxRows,
      onChange, // eslint-disable-line no-unused-vars
      onBlur, // eslint-disable-line no-unused-vars
      valueType, // eslint-disable-line no-unused-vars
      className,
      invalid,
      ...other
    } = this.props
    const { value } = this.state


    return (
      <div className={cm.wrapper}>
        <TextAreaAutosize
          {...other}
          inputRef={this.handleTextAreaRef}
          value={value}
          onChange={this.handleChange}
          onBlur={this.handleBlur}
          minRows={minRows}
          maxRows={maxRows}
          className={cx(className, { [cm.invalid]: invalid })}
        />
      </div>
    )
  }
}

export default TextArea