import React, { Component } from 'react'
import PropTypes from 'prop-types'
import Loader from 'components/Loader'
import cm from './Toggle.module.styl'
import cx from 'classnames'

class Toggle extends Component {
  static propTypes = {
    className: PropTypes.string,
    /** Enables danger (red) background when OFF */
    danger: PropTypes.bool,
    disabled: PropTypes.bool,
    label: PropTypes.string,
    leftLabel: PropTypes.string,
    loader: PropTypes.bool,
    noOnOff: PropTypes.bool,
    value: PropTypes.bool.isRequired,
    onChange: PropTypes.func,
    onFocus: PropTypes.func,
    onBlur: PropTypes.func,
    style: PropTypes.object,
    /** Small size, used in tables and lists. */
    sm: PropTypes.bool,
    xs: PropTypes.bool,
  }

  render() {
    const {
      className,
      danger,
      disabled,
      label,
      leftLabel,
      loader,
      noOnOff,
      value,
      onChange,
      onFocus,
      onBlur,
      style,
      sm,
      xs,
      ...other
    } = this.props
    return (
      <label
        className={cx(cm.wrapper, className, {
          [cm.xs]: xs,
          [cm.sm]: sm,
          [cm.danger]: danger,
          [cm.disabled]: disabled,
          [cm.noOnOff]: noOnOff,
        })}
        style={style}
      >
        {leftLabel ? <span className={cm.label}>{leftLabel}</span> : null}
        <span className={cm.input}>
          {loader && <Loader center size={sm || xs ? 16 : 28} />}
          <input
            type="checkbox"
            onChange={onChange}
            onFocus={onFocus}
            onBlur={onBlur}
            checked={value}
            disabled={disabled}
            {...other}
          />
          <i />
        </span>
        {label ? <span className={cm.label}>{label}</span> : null}
      </label>
    )
  }
}

export default Toggle
