import cm from './DateRangePicker.module.styl'
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import Dropdown from 'components/layers/Dropdown'
import DateRange from '../DateRange'
import Btn from 'components/Btn'
import SvgIcon from 'components/misc/SvgIcon'
import { isValidDate, parseDate, formatDate, formatAny } from 'utils/date'
import { getWindow } from 'utils'
import { CALENDAR } from 'constants/icons'

const format = (date, omitYear, omitMonth) =>
  formatAny(date, {
    day: 'numeric',
    month: omitMonth ? undefined : 'long',
    year: omitYear ? undefined : 'numeric',
  })

const getCalendarsCount = () => {
  const window = getWindow()
  if (window.innerWidth < 600) {
    return 1
  }
  return window.innerWidth < 1000 ? 2 : 3
}

export default class DateRangePicker extends PureComponent {
  static propTypes = {
    value: PropTypes.arrayOf(PropTypes.string),
    onChange: PropTypes.func,
  }

  state = {
    value: this.props.value,
    calendars: this.props.calendars || getCalendarsCount(),
  }

  dropdown = React.createRef()

  componentDidUpdate = (prevProps, prevState) => {
    const { value } = this.props
    if (prevProps.value !== value) {
      this.setState({ value })
    }
  }

  handleChange = e => this.setState({ value: e.target.value })

  handleApply = e => {
    this.dropdown.current.close()
    const { name, onChange } = this.props
    onChange({ target: { value: this.state.value, name } })
  }

  handleClose = e => this.dropdown.current.close()

  renderAchror = ({ open }) => {
    const { value } = this.props

    let summaryText = 'Select date range'
    if (Array.isArray(value) && isValidDate(value[0]) && isValidDate(value[1])) {
      const isSameYear = value[0].slice(0, 4) === value[1].slice(0, 4)
      const isSameMonth = value[0].slice(5, 7) === value[1].slice(5, 7)
      const start = parseDate(value[0])
      const end = parseDate(value[1])
      summaryText = `${format(start, isSameYear, isSameMonth)} – ${format(end)}`
      if (value[0] === value[1]) {
        const date = new Date()
        if (value[0] === formatDate(date)) {
          summaryText = `Today (${format(start, true)})`
        }
        date.setDate(date.getDate() - 1)
        if (value[0] === formatDate(date)) {
          summaryText = `Yesterday (${format(start, true)})`
        }
      }
    }

    return (
      <div
        className={`p-relative p-y-sm p-l-sm p-r-lg b-a rounded pointer ${open ? cm.active : ''}`}
        style={{ color: 'initial' }}
      >
        {summaryText}
        <SvgIcon i={CALENDAR} size={18} className={cm.icon} />
      </div>
    )
  }

  renderControls = () => {
    const { value } = this.state
    const [start, end] = value || []
    return (
      <React.Fragment>
        <a onClick={this.handleClose} className="p-a-sm m-r-sm">
          Close
        </a>
        <Btn primary onClick={this.handleApply} disabled={!start || !end}>
          Apply
        </Btn>
      </React.Fragment>
    )
  }

  render() {
    const { value } = this.state
    const { value: propsValue, onChange, ...rest } = this.props // eslint-disable-line no-unused-vars

    return (
      <Dropdown
        ref={this.dropdown}
        renderAnchor={this.renderAchror}
        anchorOrigin="bottom left"
        popoverOrigin="top left"
        arrow={false}
        className="m-t-xs"
      >
        <DateRange
          {...rest}
          calendars={3}
          controls={this.renderControls()}
          value={value}
          onChange={this.handleChange}
        />
      </Dropdown>
    )
  }
}
