import React from 'react'
import ReactDOM from 'react-dom'
import PropTypes from 'prop-types'
import { noop } from 'utils'
import Modal from 'components/layers/Modal'

export default class ConfirmComponent extends React.Component {
  static propTypes = {
    cancelLabel: PropTypes.string,
    cancelDisabled: PropTypes.bool,
    cancelProps: PropTypes.object,
    confirmLabel: PropTypes.string,
    confirmDisabled: PropTypes.bool,
    confirmProps: PropTypes.object,
    children: PropTypes.any,
    danger: PropTypes.bool,
    disableOverlayClose: PropTypes.bool,
    inverse: PropTypes.bool,
    loader: PropTypes.bool,
    onCancel: PropTypes.func,
    onConfirm: PropTypes.func,
    title: PropTypes.string,
  }

  static defaultProps = {
    disableOverlayClose: false,
    onCancel: noop,
    onConfirm: noop,
    width: 460,
  }

  state = {
    title: '',
    confirmLabel: '',
    cancelLabel: '',
    disableOverlayClose: false,
    body: null,
  }

  open = (title, options = {}) => {
    const { body, confirmLabel, cancelLabel, disableOverlayClose = false } = options
    this.setState({
      title,
      confirmLabel,
      cancelLabel,
      disableOverlayClose,
      body,
    })
    this.modal.open()
    return new window.Promise(resolve => (this.resolve = resolve))
  }

  close = () => {
    this.resolve && this.resolve(false)
    this.modal.close()
  }

  confirm = e => {
    this.resolve && this.resolve(true)
    this.props.onConfirm()
  }

  cancel = e => {
    e && e.preventDefault()
    this.close()
    this.props.onCancel()
  }

  handleConfirmRef = el => {
    if (!el) {
      return
    }
    const btn = ReactDOM.findDOMNode(el) // eslint-disable-line react/no-find-dom-node
    btn.focus()
  }

  handleModalRef = el => (this.modal = el)

  render() {
    const {
      danger,
      cancelLabel,
      cancelDisabled,
      cancelProps,
      confirmLabel,
      confirmDisabled,
      confirmProps,
      children,
      disableOverlayClose,
      loader,
      title,
      ...other
    } = this.props

    const buttons = [
      {
        label: this.state.cancelLabel || cancelLabel || 'Cancel',
        disabled: cancelDisabled,
        ...cancelProps,
        onClick: this.cancel,
        'data-test-id': 'modal-cancel-button-element',
      },
      {
        label: this.state.confirmLabel || confirmLabel || 'Confirm',
        disabled: confirmDisabled,
        primary: !danger,
        danger: danger,
        loader,
        ...confirmProps,
        ref: this.handleConfirmRef,
        onClick: this.confirm,
        'data-test-id': 'modal-confirm-button-element',
      },
    ]

    return (
      <Modal
        {...other}
        ref={this.handleModalRef}
        title={this.state.title || title}
        buttons={buttons}
        disableCloseButton
        disableOverlayClose={this.state.disableOverlayClose || disableOverlayClose}
        isConfirm
      >
        {this.state.body || children}
      </Modal>
    )
  }
}
