import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import Popover from 'components/layers/Popover'
import Btn from 'components/Btn'
import { noop } from 'utils'

export default class Dropdown extends PureComponent {
  static propTypes = {
    arrow: PropTypes.any,
    at: PropTypes.string,
    children: PropTypes.node,
    label: PropTypes.node,
    onClickAnchor: PropTypes.func,
    onClose: PropTypes.func,
    onOpen: PropTypes.func,
    renderAnchor: PropTypes.func,
    useLayerForClickAway: PropTypes.bool,
    onHover: PropTypes.bool,
  }

  static defaultProps = {
    arrow: true,
    at: 'bottom',
    onClickAnchor: noop,
    onClose: noop,
    onOpen: noop,
    useLayerForClickAway: false,
  }

  state = { open: false }

  anchor = React.createRef()

  close = () => this.setState({ open: false }, this.props.onClose)
  open = () => this.setState({ open: true }, this.props.onOpen)

  handleAnchorClick = e => this.open()

  handleMouseEnter = e => {
    if (!this.props.onHover) {
      return
    }
    clearTimeout(this.timer)
    if (!this.state.open) {
      this.open()
    }
  }

  handleMouseLeave = e => {
    if (!this.props.onHover) {
      return
    }
    if (e.relatedTarget !== this.popover && e.relatedTarget !== this.anchor.current) {
      this.timer = setTimeout(this.close, 300)
    }
  }

  handleRequestClose = reason =>
    reason !== 'clickAnchor' ? this.close() : this.props.onClickAnchor()

  handlePopoverRef = el => (this.popover = el)

  renderAnchor = () => {
    const { open } = this.state
    const { label, renderAnchor } = this.props
    const anchorProps = {
      ref: this.anchor,
      onClick: this.handleAnchorClick,
      onMouseEnter: this.handleMouseEnter,
      onMouseLeave: this.handleMouseLeave,
    }

    if (typeof renderAnchor === 'function') {
      return React.cloneElement(renderAnchor({ open }), anchorProps)
    }

    return <Btn {...anchorProps} label={label} active={open} />
  }

  render() {
    const { open } = this.state
    const { children, label, renderAnchor, ...rest } = this.props // eslint-disable-line no-unused-vars

    return (
      <React.Fragment>
        {this.renderAnchor()}
        <Popover
          {...rest}
          popoverRef={this.handlePopoverRef}
          open={open}
          anchor={this.anchor.current}
          onRequestClose={this.handleRequestClose}
          onMouseEnter={this.handleMouseEnter}
          onMouseLeave={this.handleMouseLeave}
        >
          {children}
        </Popover>
      </React.Fragment>
    )
  }
}
