import cm from './Modal.module.styl'
import cx from 'classnames'
import React from 'react'
import PropTypes from 'prop-types'
import Scrollbars from 'react-custom-scrollbars'
import { noop, getWindow } from 'utils'
import RenderToLayer from 'components/layers/RenderToLayer'
import Btn from 'components/Btn'
import SvgIcon from 'components/misc/SvgIcon'
import { MODAL_CLOSE } from 'constants/icons'
import { CLOSE_REASONS } from './constants'

export default class Modal extends React.Component {
  static propTypes = {
    buttons: PropTypes.array,
    children: PropTypes.any,
    className: PropTypes.string,
    disableClose: PropTypes.bool,
    disableEscapeClose: PropTypes.bool,
    disableOverlayClose: PropTypes.bool,
    disableCloseButton: PropTypes.bool,
    headerButtons: PropTypes.array,
    isConfirm: PropTypes.bool,
    noContentPadding: PropTypes.bool,
    onClose: PropTypes.func,
    onOpen: noop,
    onRequestClose: noop,
    open: PropTypes.bool,
    scrollable: PropTypes.bool,
    title: PropTypes.any,
    width: PropTypes.number,
  }

  static defaultProps = {
    buttons: [],
    headerButtons: [],
    modalComponent: 'div',
    onRequestClose: noop,
    onClose: noop,
    onOpen: noop,
  }

  static getDerivedStateFromProps(nextProps, prevState) {
    if ('open' in nextProps) {
      const { open } = nextProps
      return { open }
    }
    return null
  }

  state = { open: false }

  componentDidUpdate(prevProps, prevState) {
    if (this.state.open !== !prevState.open) {
      this.props[`on${this.state.open ? 'Open' : 'Close'}`]()
    }
  }

  close = (reason, e) => {
    if (this.props.disableClose) {
      return
    }

    if ('open' in this.props) {
      this.props.onRequestClose(reason, e)
    } else {
      this.setState({ open: false })
    }
  }

  open = () => this.setState({ open: true })

  handleClickAway = e => !this.props.disableOverlayClose && this.close(CLOSE_REASONS.CLICK_AWAY, e)

  handleEscapeKeyDown = e => !this.props.disableEscapeClose && this.close(CLOSE_REASONS.ESC, e)

  // TODO: manage focus
  handleWindowRef = el => {
    // if (el) {
    //   el.focus()
    // } else if (this.previousFocusedElement) {
    //   this.previousFocusedElement.focus()
    // }
  }

  render() {
    const { open } = this.state
    const {
      buttons,
      children,
      className,
      disableClose,
      disableCloseButton,
      headerButtons,
      isConfirm,
      noContentPadding,
      scrollable,
      title,
      width,
    } = this.props

    const hasHeaderButtons = headerButtons.length > 0
    const hasHeader = !!(title || hasHeaderButtons)
    const hasCloseBtn = !disableClose && !disableCloseButton
    const hasButtons = buttons.length > 0
    const offsetY = hasButtons ? 160 : 112
    const body = children ? (
      <div className={cx({ 'p-x p-y-sm': !noContentPadding })}>{children}</div>
    ) : null

    return (
      <RenderToLayer
        className={cm.overlay}
        render={this.renderModal}
        open={!!open}
        onEscapeKeyDown={this.handleEscapeKeyDown}
        onClickAway={this.handleClickAway}
      >
        <div
          ref={this.handleWindowRef}
          className={cx(cm.modal, className)}
          style={{ width }}
          tabIndex={-1}
        >
          {hasCloseBtn && (
            <SvgIcon i={MODAL_CLOSE} size={20} onClick={this.close} className={cm.close} />
          )}

          {hasHeader && (
            <div className={cx('p-y-sm p-x row center')}>
              <div className={cx(cm.title, 'col-auto')}>{title}</div>
              {hasHeaderButtons && <div className="col row end">{headerButtons}</div>}
            </div>
          )}

          {body && (
            <div className={cx(hasHeader && !isConfirm && 'b-t')}>
              {scrollable ? (
                <Scrollbars autoHeight autoHeightMax={getWindow().innerHeight - offsetY}>
                  {body}
                </Scrollbars>
              ) : (
                body
              )}
            </div>
          )}

          {hasButtons && (
            <div className={cx('p-y-sm p-x b-t row', buttons.length > 1 ? 'between' : 'end')}>
              {buttons.map((props, i) => <Btn {...props} key={i} />)}
            </div>
          )}
        </div>
      </RenderToLayer>
    )
  }
}
