import React from 'react'
import { storiesOf } from '@storybook/react'
import { Confirm, Modal, Btn } from '@manychat/manyui'

class Wrapper extends React.Component {
  state = {}

  handleBtnRef = el => el && (this[`btn${el.props.name}`] = el)

  handleShowModalClick = e => {
    const prop = `show${e.currentTarget.name}`
    this.setState({ [prop]: !this.state[prop] })
  }

  handleModalRequestClose = (name, reason, e) => this.setState({ [`show${name}`]: false })

  render() {
    return (
      <div className="p-a">
        <Btn ref={this.handleBtnRef} name="M1" onClick={this.handleShowModalClick}>
          Modal With Title
        </Btn>
        <Modal
          open={!!this.state['showM1']}
          onRequestClose={this.handleModalRequestClose.bind(this, 'M1')}
          title={'Hello Modal'}
        >
          <div className="p-a-sm">
            <p>
              Typography is the art and technique of arranging type to make written language
              legible, readable, and appealing when displayed
            </p>
          </div>
        </Modal>

        <Btn ref={this.handleBtnRef} name="M2" onClick={this.handleShowModalClick} className="m-l">
          Modal With Title Buttons
        </Btn>
        <Modal
          open={!!this.state['showM2']}
          onRequestClose={this.handleModalRequestClose.bind(this, 'M2')}
          title={'Title With Buttons'}
          headerButtons={[<Btn key="1">Tag Segment</Btn>]}
        >
          <div className="p-a-sm">
            <p>
              Typography is the art and technique of arranging type to make written language
              legible, readable, and appealing when displayed
            </p>
          </div>
        </Modal>

        <Btn ref={this.handleBtnRef} name="M3" onClick={this.handleShowModalClick} className="m-l">
          Modal With Tall Content
        </Btn>
        <Modal
          open={!!this.state['showM3']}
          onRequestClose={this.handleModalRequestClose.bind(this, 'M3')}
          title={'Title With Tall Content'}
          buttons={[{ label: 'Close' }]}
          scrollable
        >
          <div className="p-x">
            <p>
              Typography is the art and technique of arranging type to make written language
              legible, readable, and appealing when displayed
            </p>
            <h6>h6. Example heading</h6>
            <h5>h5. Example heading</h5>
            <h4>h4. Example heading</h4>
            <h3>h3. Example heading</h3>
            <h2>h2. Example heading</h2>
            <h1>h1. Example heading</h1>
            <div className="m-y-lg p-a-lg bg-primary" />
            <p>
              Typography is the art and technique of arranging type to make written language
              legible, readable, and appealing when displayed
            </p>
          </div>
        </Modal>

        <Btn name="M2" onClick={() => this.confirm.open()} className="m-l">
          Confirm
        </Btn>
        <Confirm
          ref={el => (this.confirm = el)}
          title="Are you sure?"
          onConfirm={() => {
            this.confirm.close()
            console.log('Confirmed')
          }}
        />
      </div>
    )
  }
}

const stories = storiesOf('Modal', module)
stories.add('default', () => <Wrapper />)
