import cm from './Popover.module.styl'
import cx from 'classnames'
import React from 'react'
import PropTypes from 'prop-types'
import PopoverBase from './PopoverBase'
import { AT_MAPPING, ARROW_ORIGINS, ARROW_MARGINS, ARROW_AXIS, ARROW_OPPOSITES } from './constants'

export default class Popover extends React.PureComponent {
  static propTypes = {
    /**
     * Snap element for a popover. Can be HTML element or React element
     */
    anchor: PropTypes.any,
    /**
     * Anchor snap point.
     */
    anchorOrigin: PropTypes.string,
    /**
     * Adds popover arrow.
     * Can be bool when used with 'at' prop, otherwise should be
     * arrow position string
     */
    arrow: PropTypes.oneOfType([
      PropTypes.bool,
      PropTypes.oneOf(['top', 'bottom', 'left', 'right']),
    ]),
    at: PropTypes.oneOf(['top', 'bottom', 'left', 'right']),
    /**
     * Specifies ability to auto position popover when it goes offscreen
     * It's possible to set this prop separately for 'x' and 'y' axis
     * E.g. 'none auto' will prevent 'x' auto positioning
     * Use 'flip' and 'shift' values to specify certain auto position mechanism
     */
    autoPosition: PropTypes.string,
    className: PropTypes.string,
    children: PropTypes.any,
    fitTargetWidth: PropTypes.bool,
    /** TODO */
    fullscreenOnMobile: PropTypes.bool,
    onRequestClose: PropTypes.func,
    open: PropTypes.bool,
    popoverOrigin: PropTypes.string,
    useLayerForClickAway: PropTypes.bool,
  }

  static defaultProps = {}

  state = {}

  getArrowData = arrow => {
    const axis = ARROW_AXIS[arrow]
    const axisData = this.state[`${axis}Data`] || {}
    const arrowDirection = axisData.position === 'flip' ? ARROW_OPPOSITES[arrow] : arrow
    return {
      arrowDirection,
      arrowOrigin: `center ${arrowDirection}`,
      arrowHidden: axisData.position === 'shift',
    }
  }

  getOrigins = (at, anchorOrigin, popoverOrigin) => ({
    anchorOrigin: this.props.anchorOrigin || (AT_MAPPING[at] || {}).anchorOrigin,
    popoverOrigin: this.props.popoverOrigin || (AT_MAPPING[at] || {}).popoverOrigin,
  })

  handleAxisAutoPositon = (axis, data) => this.setState({ [`${axis}Data`]: data })

  render() {
    const {
      anchor,
      anchorOrigin: ao,
      arrow: propsArrow,
      at,
      children,
      className,
      fullscreenOnMobile,
      open,
      popoverOrigin: po,
      ...rest
    } = this.props

    const { anchorOrigin, popoverOrigin } = this.getOrigins(at, ao, po)

    const arrow = at && propsArrow === true ? at : propsArrow
    const withArrow = !!arrow
    const { arrowDirection, arrowOrigin, arrowHidden } = this.getArrowData(arrow)

    const fullscreen = fullscreenOnMobile // TODO: && isMobile
    const cn = cx('b-a rounded bg-white shadow', className, {
      [ARROW_MARGINS[arrowDirection]]: withArrow,
    })

    return (
      <React.Fragment>
        <PopoverBase
          {...rest}
          anchor={anchor}
          anchorOrigin={anchorOrigin}
          fullscreen={fullscreen}
          open={open}
          onAxisAutoPositon={this.handleAxisAutoPositon}
          popoverOrigin={popoverOrigin}
        >
          <div className={cn}>{children}</div>
        </PopoverBase>
        {withArrow && (
          <PopoverBase
            open={open}
            anchor={anchor}
            anchorOrigin={arrowOrigin || anchorOrigin}
            popoverOrigin={ARROW_ORIGINS[arrowDirection]}
            autoPosition={false}
            useLayerForClickAway={false}
            className="p-events-none"
          >
            <div className={cx(cm.arrow, cm[arrowDirection], { 'd-none': arrowHidden })} />
          </PopoverBase>
        )}
      </React.Fragment>
    )
  }
}
