/**
 * @class RenderToLayer
 */

import React from 'react'
import PropTypes from 'prop-types'
import { createPortal } from 'react-dom'
import { noop, DOM } from 'utils'
import { withHanlder } from './utils/stoppedEvents'
import { eventsManager } from './utils'

const clickAwayStyle = {
  position: 'fixed',
  top: 0,
  bottom: 0,
  left: 0,
  right: 0,
  zIndex: 1010,
}

class RenderToLayer extends React.Component {
  static propTypes = {
    className: PropTypes.string,
    children: PropTypes.any,
    style: PropTypes.object,
    onClick: PropTypes.func,
    onClickAway: PropTypes.func,
    onEscapeKeyDown: PropTypes.func,
    open: PropTypes.bool.isRequired,
    useLayerForClickAway: PropTypes.bool,
  }

  static defaultProps = {
    onClick: noop,
    onClickAway: noop,
    onEscapeKeyDown: noop,
    useLayerForClickAway: true,
  }

  constructor(props) {
    super(props)
    this.handler = (eventName, e) => {
      if (typeof this.props[eventName] === 'function') {
        this.props[eventName](e)
      }
      e.stopPropagation()
    }
    this.events = withHanlder(this.handler)
  }

  getLayer() {
    return this.layer
  }

  handleWindowClick = (event, mousedownEvent) => {
    if (!this.props.open) {
      return
    }

    const el = this.layer
    if (
      DOM.isClickInElement(event, el.firstChild) ||
      DOM.isClickInElement(mousedownEvent, el.firstChild)
    ) {
      event.stopPropagationToLayers()
      // This event handled in default handler for all events. May be we should hanlde it here for right order
      // this.props.onClick(event)
    } else {
      this.props.onClickAway(event, mousedownEvent)
    }
  }

  handleEscapeKeyDown = e => this.props.onEscapeKeyDown(e)

  handleLayer = el => {
    if (el) {
      if (!this.layer) {
        eventsManager.addEventListener('click', this.handleWindowClick)
        eventsManager.addEventListener('esckeydown', this.handleEscapeKeyDown)
      }
    } else if (this.layer) {
      eventsManager.removeEventListener('click', this.handleWindowClick)
      eventsManager.removeEventListener('esckeydown', this.handleEscapeKeyDown)
    }
    this.layer = el
  }

  render() {
    const { open, className, children, style, useLayerForClickAway } = this.props

    if (!open) {
      return null
    }

    const _style = { position: 'relative', zIndex: 1010 }
    Object.assign(_style, useLayerForClickAway ? clickAwayStyle : undefined, style)

    return createPortal(
      <div ref={this.handleLayer} style={_style} className={className} {...this.events}>
        {children}
      </div>,
      document.body,
    )
  }
}

export default RenderToLayer
