import cm from './MainMenu.module.styl'
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import MenuCategory from './MenuCategory'

export default class MainMenu extends PureComponent {
  static propTypes = {
    categories: PropTypes.arrayOf(
      PropTypes.shape({
        parentId: PropTypes.string,
        parentIndex: PropTypes.any,
        caption: PropTypes.string,
        items: PropTypes.array,
      }),
    ),
    activeIndex: PropTypes.number,
    onOpen: PropTypes.func,
    isPro: PropTypes.bool,
  }

  static defaultProps = {
    categories: [],
  }

  state = {
    activeIndex: 0,
  }

  handleItemClick = menuItem => {
    const { categories } = this.props

    if (menuItem.type === 'nested') {
      const index = categories.findIndex(c => c.parentId === menuItem.id) || 0
      this.setState({ activeIndex: index })
    }
  }

  handleBackClick = index => this.setState({ activeIndex: index })

  render() {
    const { activeIndex } = this.state
    const { categories } = this.props

    return (
      <div className="p-relative fbm-bg-menu fbm-b-t-light fbm-text-md">
        <div className={cx(cm.swipe, 'm-x-auto m-y-xs fbm-bg-border')} />
        {categories.map((category, i) => {
          return (
            <div
              key={i}
              className={cx(cm.category, {
                [cm.hideAtLeft]: i < activeIndex,
                [cm.hideAtRight]: i > activeIndex,
              })}
            >
              <MenuCategory
                caption={category.caption}
                index={i}
                items={category.items}
                onBackClick={this.handleBackClick}
                onItemClick={this.handleItemClick}
                parentIndex={category.parentIndex}
              />
            </div>
          )
        })}
      </div>
    )
  }
}
