import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import SvgIcon from 'components/misc/SvgIcon'
import { KEYBOARD_ARROW_LEFT_THIN, KEYBOARD_ARROW_RIGHT_THIN } from 'constants/icons'

const SendMessage = () => (
  <div className="p-b-sm p-x">
    <div
      className="b-a p-y-xs p-x-sm fbm-bg-menu-2 fbm-text-secondary"
      style={{ borderRadius: '1rem' }}
    >
      Send a message...
    </div>
  </div>
)

export default class MenuCategory extends PureComponent {
  static propTypes = {
    caption: PropTypes.string,
    index: PropTypes.number,
    items: PropTypes.array,
    onBackClick: PropTypes.func.isRequired,
    onItemClick: PropTypes.func.isRequired,
    parentIndex: PropTypes.number,
  }

  handleClick = e => {
    const { items, onItemClick } = this.props
    const { id } = e.currentTarget.dataset

    const menuItem = items.find(i => i.id == id)
    onItemClick(menuItem)
  }

  handleBackClick = e => {
    const { onBackClick, parentIndex } = this.props
    onBackClick(parentIndex)
  }

  render() {
    const { index, items, caption, parentIndex } = this.props

    return (
      <div>
        {index === 0 ? (
          <SendMessage />
        ) : (
          <div className="row middle fbm-b-b-light">
            <div
              className="col-auto text-primary pointer"
              onClick={this.handleBackClick}
              data-index={parentIndex}
            >
              <SvgIcon i={KEYBOARD_ARROW_LEFT_THIN} size={32} />
            </div>
            <div className="col p-l p-r-lg text-center text-ellipsis font-semibold">{caption}</div>
          </div>
        )}
        {items.map((menuItem, i) => {
          const isSubMenu = menuItem.type === 'nested'
          const isLast = i === items.length - 1

          return (
            <div
              key={menuItem.id}
              className="p-l fbm-bg-h-menu-2 pointer"
              onClick={this.handleClick}
              data-id={menuItem.id}
            >
              <div
                className={cx('row middle', {
                  'fbm-b-b-light': !isLast,
                })}
                style={{ height: 32 }}
              >
                <div className={'col text-ellipsis'}>{menuItem.caption}</div>

                {isSubMenu && (
                  <div className={'col-auto fbm-text-secondary'}>
                    <SvgIcon i={KEYBOARD_ARROW_RIGHT_THIN} size={24} />
                  </div>
                )}
              </div>
            </div>
          )
        })}
      </div>
    )
  }
}
