import cm from './Cards.module.styl'
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import Card from './Card'
import SvgIcon from 'components/misc/SvgIcon'
import { KEYBOARD_ARROW_LEFT_THIN, KEYBOARD_ARROW_RIGHT_THIN } from 'constants/icons'

const SCROLL_STEP = 250

const SCROLL_WIDTH = getScrollbarWidth()

export default class Cards extends PureComponent {
  static propTypes = {
    items: PropTypes.array,
  }

  handlePrevClick = () => this.scroller && (this.scroller.scrollLeft -= SCROLL_STEP)
  handleNextClick = () => this.scroller && (this.scroller.scrollLeft += SCROLL_STEP)

  handleScrollerRef = el => (this.scroller = el)

  render() {
    const { items } = this.props

    return (
      <div className={cm.wrapper}>
        {items.length > 1 && (
          <React.Fragment>
            <SvgIcon
              i={KEYBOARD_ARROW_LEFT_THIN}
              onClick={this.handlePrevClick}
              className={cx(cm.arrow, cm.prev, 'shadow')}
              size={32}
            />
            <SvgIcon
              i={KEYBOARD_ARROW_RIGHT_THIN}
              onClick={this.handleNextClick}
              className={cx(cm.arrow, cm.next, 'shadow')}
              size={32}
            />
          </React.Fragment>
        )}
        <div
          ref={this.handleScrollerRef}
          className={cm.scroller}
          style={{ marginBottom: -SCROLL_WIDTH }}
        >
          {items.map((card, index) => (
            <Card key={index} item={card} />
          ))}
        </div>
      </div>
    )
  }
}

function getScrollbarWidth() {
  if (typeof document === 'undefined') {
    return 0
  }
  const outer = document.createElement('div')
  outer.style.visibility = 'hidden'
  outer.style.width = '100px'

  document.body.appendChild(outer)

  const widthNoScroll = outer.offsetWidth
  // force scrollbars
  outer.style.overflow = 'scroll'

  // add innerdiv
  var inner = document.createElement('div')
  inner.style.width = '100%'
  outer.appendChild(inner)

  var widthWithScroll = inner.offsetWidth

  // remove divs
  outer.parentNode.removeChild(outer)

  return widthNoScroll - widthWithScroll
}
