import cm from './List.module.styl'
import commonCm from '../Message.module.styl'
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import Buttons from '../Buttons'

export default class Cards extends PureComponent {
  static propTypes = {
    items: PropTypes.array,
    topElementStyle: PropTypes.oneOf(['compact', 'large']),
  }

  render() {
    const { items, topElementStyle } = this.props
    const isTopElementLarge = topElementStyle === 'large'

    return (
      <div className={cm.wrapper}>
        {items.map((item, index) => {
          const { buttons, image, title, subtitle } = item
          const isImgLarge = isTopElementLarge && index === 0
          return (
            <div key={index} className={`${cm.element} ${isImgLarge ? cm.large : ''}`}>
              <div className={cm.content}>
                <div className="fbm-text-md">{title}</div>
                <div className={`${commonCm.clamp2Lines} p-t-xs fbm-text-secondary`}>
                  {subtitle}
                </div>
                {Array.isArray(buttons) &&
                  buttons.length > 0 && (
                    <div className="p-t-sm">
                      <Buttons items={buttons} sm />
                    </div>
                  )}
              </div>
              {!!image && (
                <div className={cm.img}>
                  <img src={image.img_big} alt={image.title} />
                </div>
              )}
            </div>
          )
        })}
      </div>
    )
  }
}
