import cm from './Message.module.styl'
import React, { PureComponent } from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import Buttons from './Buttons'
import List from './List'
import Cards from './Cards'
import Audio from './media/Audio'
import Video from './media/Video'

class Attachment extends PureComponent {
  static propTypes = {
    attachment: PropTypes.any,
    attachmentType: PropTypes.oneOf(['file', 'audio', 'video', 'image']),
  }

  static defaultProps = {}

  render() {
    const { attachmentType } = this.props
    const attachment = this.props.attachment || {}

    switch (attachmentType) {
      case 'image': {
        const src = attachment.gif || attachment.img_big
        return <img src={src} alt="" />
      }
      case 'audio': {
        return <Audio {...attachment} />
      }
      case 'video': {
        return <Video {...attachment} />
      }
    }

    return null
  }
}

export default class Message extends PureComponent {
  static propTypes = {
    block: PropTypes.any,
    fromSubscriber: PropTypes.bool,
  }

  render() {
    const { block, fromSubscriber } = this.props
    const messageCn = {
      [cm.message]: true,
    }

    let msg
    switch (block.type) {
      case 'text':
        msg = block.text
        messageCn[cm.text] = true
        messageCn['d-inline-flex'] = !Array.isArray(block.buttons) || !block.buttons.length
        break
      case 'attachment':
        msg = <Attachment {...block} />
        messageCn['d-inline-flex'] = block.attachmentType === 'audio'
        break
      case 'list':
        msg = <List {...block} />
        break
      case 'cards':
        msg = <Cards {...block} />
        messageCn[cm.cards] = true
        break
    }

    const withButtons = Array.isArray(block.buttons) && block.buttons.length > 0

    return (
      <div className={cx(cm.wrapper, { [cm.fromSubscriber]: fromSubscriber })}>
        <div className={cx(messageCn)}>
          {msg}
          {withButtons && <Buttons items={block.buttons} />}
        </div>
      </div>
    )
  }
}
