import React, { PureComponent } from 'react'

export default function MediaHOC(WrappedComponent) {
  return class MediaPlayer extends PureComponent {
    state = {
      currentTime: 0,
      duration: 0,
      playing: false,
    }

    formatDuration = () => {
      const { currentTime, duration } = this.state
      if (duration === 0) {
        return '-:--'
      }
      const d = Math.floor(duration - currentTime)
      return `${Math.floor(d / 60)}:${('0' + (d % 60)).slice(-2)}`
    }

    handleRef = el => {
      if (!el) {
        return
      }
      this.player = el
      el.addEventListener('loadedmetadata', e => this.setState({ duration: e.target.duration }))
      el.addEventListener('ended', e => this.setState({ playing: false, currentTime: 0 }))
      el.addEventListener('timeupdate', e => this.setState({ currentTime: e.target.currentTime }))
    }

    handlePlayClick = e => {
      if (!this.player) {
        return
      }
      if (this.state.playing) {
        this.player.pause()
        this.setState({ playing: false })
      } else {
        this.player
          .play()
          .then(() => this.setState({ playing: true }))
          .catch(err => {
            console.warn(err)
          })
      }
    }

    render() {
      return (
        <WrappedComponent
          ref={this.handleRef}
          {...this.state}
          formatDuration={this.formatDuration}
          onPlayClick={this.handlePlayClick}
          {...this.props}
        />
      )
    }
  }
}
