import cm from './SvgIcon.module.styl'
import React from 'react'
import PropTypes from 'prop-types'

/**
 * SvgIcon
 * Component for displaying material design icons with inline SVG
 * For icons search at https://material.io/icons/ and extract `d` attr from svg paths
 * @param {*} props
 */
const SvgIcon = ({
  i,
  size = '1rem',
  fill,
  valign = 'bottom',
  style,
  className,
  rotate,
  ...other
}) => {
  const _size = typeof size === 'number' ? size + 'px' : size
  const componentStyle = {
    width: _size,
    height: _size,
  }
  if (valign) {
    componentStyle.verticalAlign = valign
  }
  if (fill) {
    componentStyle.fill = fill
  }
  if (rotate) {
    componentStyle.transform = `rotate(${rotate}deg)`
  }
  const cn = `${cm.icon} ${className}`
  return (
    <svg
      {...other}
      viewBox="0 0 24 24"
      style={Object.assign({}, componentStyle, style)}
      className={cn}
    >
      {(Array.isArray(i) ? i : [i]).map((path, i) => {
        path = typeof path === 'string' ? { d: path } : path
        return <path key={i} d={path.d} fill={path.fill} />
      })}
      <path d="M0 0h24v24H0z" fill="none" />
    </svg>
  )
}

SvgIcon.propTypes = {
  i: PropTypes.oneOfType([PropTypes.string, PropTypes.object, PropTypes.array]).isRequired,
  size: PropTypes.number,
  rotate: PropTypes.number,
  fill: PropTypes.string,
  valign: PropTypes.string,
  style: PropTypes.object,
  className: PropTypes.string,
}

export default SvgIcon
