export const isDescendant = (parent, child) => {
  if (typeof parent.contains === 'function') {
    return parent.contains(child)
  }

  let node = child.parentNode

  while (node !== null) {
    if (node === parent) {
      return true
    }
    node = node.parentNode
  }

  return false
}

export const isClickInElement = (e, el) => {
  if (el === e.target) {
    return true
  }

  const rect = el.getBoundingClientRect()
  const clickInRectangle =
    e.clientX > rect.left &&
    e.clientX < rect.right &&
    e.clientY > rect.top &&
    e.clientY < rect.bottom

  if (clickInRectangle) {
    return true
  }

  if (e.target != null && isDescendant(el, e.target)) {
    return true
  }

  return false
}

export const HTMLNodeType = {
  ELEMENT_NODE: 1,
}

const isScrollable = element => {
  const style = window.getComputedStyle(element)
  const overflowY = style['overflow-y']
  const overflowX = style['overflow-x']
  return (
    ((overflowY === 'scroll' || overflowY === 'auto') &&
      element.scrollHeight > element.clientHeight) ||
    ((overflowX === 'scroll' || overflowX === 'auto') && element.scrollWidth > element.clientWidth)
  )
}

export const getScrollableParents = element => {
  const res = []
  if (element == null) {
    return res
  }

  let wrapper = element.parentNode
  // if (wrapper == null) {
  //   return res
  // }

  while (wrapper) {
    if (wrapper === window || wrapper === window.document || wrapper == window.document.body) {
      break
    }
    if (isScrollable(wrapper)) {
      res.push(wrapper)
    }
    wrapper = wrapper.parentNode
  }

  return res
}
