import { parsePosition } from './geometry'

describe('parsePosition', () => {
  test('returns x=50 and y=50 for empty value', () => {
    expect(parsePosition()).toEqual({ x: 50, xUnits: '%', y: 50, yUnits: '%' })
  })

  test('returns passed default for empty value', () => {
    expect(parsePosition(null, { x: 21, y: 32 })).toEqual({ x: 21, y: 32 })
  })

  test('returns same x and y for 1-value syntax', () => {
    expect(parsePosition('center')).toEqual({ x: 50, xUnits: '%', y: 50, yUnits: '%' })
  })

  test('returns x=0 if value contains "left"', () => {
    expect(parsePosition('left bottom')).toEqual({ x: 0, xUnits: '%', y: 100, yUnits: '%' })
  })

  test('returns x=100 if value contains "right"', () => {
    expect(parsePosition('top right')).toEqual({ x: 100, xUnits: '%', y: 0, yUnits: '%' })
  })

  test('returns x=100 if value contains "right" and "center"', () => {
    expect(parsePosition('center right')).toEqual({ x: 100, xUnits: '%', y: 50, yUnits: '%' })
  })

  test('returns correct x for 1-value percentage syntax', () => {
    expect(parsePosition('83%')).toEqual({ x: 83, xUnits: '%', y: 50, yUnits: '%' })
  })

  test('returns correct x for 1-value pixels syntax', () => {
    expect(parsePosition('12px')).toEqual({ x: 12, xUnits: 'px', y: 50, yUnits: '%' })
  })

  test('returns correct x and y for 2-value percentage syntax', () => {
    expect(parsePosition('68% 22%')).toEqual({ x: 68, xUnits: '%', y: 22, yUnits: '%' })
  })

  test('returns correct x and y for 2-value pixels and percentage syntax', () => {
    expect(parsePosition('30px 80%')).toEqual({ x: 30, xUnits: 'px', y: 80, yUnits: '%' })
  })

  test('returns correct x and y for 2-value negative float pixels', () => {
    expect(parsePosition('-30px -80.5px')).toEqual({ x: -30, xUnits: 'px', y: -80.5, yUnits: 'px' })
  })
})
